Array(extent)
###############

.. doxygenfunction:: librapid::Array::Array(const librapid::Extent &extent, librapid::Datatype dtype = Datatype::FLOAT64, librapid::Accelerator location = Accelerator::CPU)
.. doxygenfunction:: librapid::Array::Array(const librapid::Extent &extent, std::string dtype = "float64", librapid::Accelerator location = Accelerator::CPU)
.. doxygenfunction:: librapid::Array::Array(const librapid::Extent &extent, librapid::Datatype dtype = Datatype::FLOAT64, std::string accelerator = "cpu")
.. doxygenfunction:: librapid::Array::Array(const librapid::Extent &extent, std::string dtype = "float64", std::string accelerator = "cpu")
